@@ -42,59 +42,6 @@ eel_accessibility_set_up_label_widget_relation (GtkWidget *label, GtkWidget *wid
 	atk_object_add_relationship (atk_widget, ATK_RELATION_LABELLED_BY, atk_label);
 }
 
-GType
-eel_accessibility_create_accessible_gtype (const char *type_name,
-					   GtkWidget *widget,
-					   GClassInitFunc class_init)
-{
-	GType atk_type, parent_atk_type;
-	GTypeQuery query;
-	AtkObject *parent_atk;
-	GtkWidgetClass *parent_class, *klass;
-
-	if ((atk_type = g_type_from_name (type_name))) {
-		return atk_type;
-	}
-
-	klass = GTK_WIDGET_CLASS (G_OBJECT_GET_CLASS (widget));
-	parent_class = klass;
-
-	while (klass->get_accessible == parent_class->get_accessible) {
-		parent_class = g_type_class_peek_parent (parent_class);
-	}
-
-	parent_atk = parent_class->get_accessible (widget);
-	parent_atk_type = G_TYPE_FROM_INSTANCE (parent_atk);
-
-	if (!parent_atk_type) {
-		return G_TYPE_INVALID;
-	}
-
-	/* Figure out the size of the class and instance 
-	 * we are deriving from
-	 */
-	g_type_query (parent_atk_type, &query);
-
-	/* Register the type */
-	return g_type_register_static_simple (parent_atk_type, type_name,
-					      query.class_size, class_init,
-					      query.instance_size, NULL, 0);
-}
-
-
-static GQuark
-get_quark_accessible (void)
-{
-	static GQuark quark_accessible_object = 0;
-
-	if (!quark_accessible_object) {
-		quark_accessible_object = g_quark_from_static_string
-			("accessible-object");
-	}
-
-	return quark_accessible_object;
-}
-
 static GQuark
 get_quark_gobject (void)
 {
@@ -108,20 +55,6 @@ get_quark_gobject (void)
 	return quark_accessible_gobject;
 }
 
-/**
- * eel_accessibility_get_atk_object:
- * @object: a GObject of some sort
- * 
- * gets an AtkObject associated with a GObject
- * 
- * Return value: the associated accessible if one exists or NULL
- **/
-AtkObject *
-eel_accessibility_get_atk_object (gpointer object)
-{
-	return g_object_get_qdata (object, get_quark_accessible ());
-}
-
 /**
  * eel_accessibility_get_gobject:
  * @object: an AtkObject
@@ -137,43 +70,6 @@ eel_accessibility_get_gobject (AtkObject *object)
 	return g_object_get_qdata (G_OBJECT (object), get_quark_gobject ());
 }
 
-static void
-eel_accessibility_destroy (gpointer data,
-			   GObject *where_the_object_was)
-{
-	g_object_set_qdata
-		(G_OBJECT (data), get_quark_gobject (), NULL);
-	atk_object_notify_state_change
-		(ATK_OBJECT (data), ATK_STATE_DEFUNCT, TRUE);
-	g_object_unref (data);
-}
-
-/**
- * eel_accessibility_set_atk_object_return:
- * @object: a GObject
- * @atk_object: it's AtkObject
- * 
- * used to register and return a new accessible object for something
- * 
- * Return value: @atk_object.
- **/
-AtkObject *
-eel_accessibility_set_atk_object_return (gpointer   object,
-					 AtkObject *atk_object)
-{
-	atk_object_initialize (atk_object, object);
-
-	if (!ATK_IS_GOBJECT_ACCESSIBLE (atk_object)) {
-		g_object_set_qdata_full
-			(object, get_quark_accessible (), atk_object,
-			 (GDestroyNotify)eel_accessibility_destroy);
-		g_object_set_qdata
-			(G_OBJECT (atk_object), get_quark_gobject (), object);
-	}
-
-	return atk_object;
-}
-
 static GailTextUtil *
 get_simple_text (gpointer object)
 {
