@@ -79,7 +79,7 @@ nautilus_clipboard_monitor_get (void)
 		eel_debug_call_at_shutdown (destroy_clipboard_monitor);
 		
 		clipboard = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
-		g_signal_connect (clipboard, "owner_change",
+		g_signal_connect (clipboard, "owner-change",
 				  G_CALLBACK (nautilus_clipboard_monitor_emit_changed), NULL);
 	}
 	return clipboard_monitor;
@@ -165,7 +165,7 @@ nautilus_clipboard_monitor_class_init (NautilusClipboardMonitorClass *klass)
 	copied_files_atom = gdk_atom_intern ("x-special/gnome-copied-files", FALSE);
 
 	signals[CLIPBOARD_CHANGED] =
-		g_signal_new ("clipboard_changed",
+		g_signal_new ("clipboard-changed",
 		              G_TYPE_FROM_CLASS (klass),
 		              G_SIGNAL_RUN_LAST,
 		              G_STRUCT_OFFSET (NautilusClipboardMonitorClass, clipboard_changed),
@@ -173,7 +173,7 @@ nautilus_clipboard_monitor_class_init (NautilusClipboardMonitorClass *klass)
 		              g_cclosure_marshal_VOID__VOID,
 		              G_TYPE_NONE, 0);
 	signals[CLIPBOARD_INFO] =
-		g_signal_new ("clipboard_info",
+		g_signal_new ("clipboard-info",
 		              G_TYPE_FROM_CLASS (klass),
 		              G_SIGNAL_RUN_LAST,
 		              G_STRUCT_OFFSET (NautilusClipboardMonitorClass, clipboard_info),
