@@ -182,28 +182,43 @@ list_changed (NautilusColumnChooser *chooser)
 }
 
 static void
-visible_toggled_callback (GtkCellRendererToggle *cell, 
-			  char *path_string,
-			  gpointer user_data)
+toggle_path (NautilusColumnChooser *chooser,
+             GtkTreePath *path)
 {
-	NautilusColumnChooser *chooser;
-	GtkTreePath *path;
 	GtkTreeIter iter;
 	gboolean visible;
 	
-	chooser = NAUTILUS_COLUMN_CHOOSER (user_data);
-
-	path = gtk_tree_path_new_from_string (path_string);
-	gtk_tree_model_get_iter (GTK_TREE_MODEL (chooser->details->store), 
+	gtk_tree_model_get_iter (GTK_TREE_MODEL (chooser->details->store),
 				 &iter, path);
 	gtk_tree_model_get (GTK_TREE_MODEL (chooser->details->store),
 			    &iter, COLUMN_VISIBLE, &visible, -1);
 	gtk_list_store_set (chooser->details->store,
 			    &iter, COLUMN_VISIBLE, !visible, -1);
-	gtk_tree_path_free (path);
 	list_changed (chooser);
 }
 
+
+static void
+visible_toggled_callback (GtkCellRendererToggle *cell,
+			  char *path_string,
+			  gpointer user_data)
+{
+	GtkTreePath *path;
+	
+	path = gtk_tree_path_new_from_string (path_string);
+	toggle_path (NAUTILUS_COLUMN_CHOOSER (user_data), path);
+	gtk_tree_path_free (path);
+}
+
+static void
+view_row_activated_callback (GtkTreeView *tree_view,
+                             GtkTreePath *path,
+                             GtkTreeViewColumn *column,
+                             gpointer user_data)
+{
+	toggle_path (NAUTILUS_COLUMN_CHOOSER (user_data), path);
+}
+
 static void
 selection_changed_callback (GtkTreeSelection *selection, gpointer user_data)
 {
@@ -241,7 +256,10 @@ add_tree_view (NautilusColumnChooser *chooser)
 	g_object_unref (store);
 
 	gtk_tree_view_set_reorderable (GTK_TREE_VIEW (view), TRUE);
-	
+
+	g_signal_connect (view, "row-activated",
+	                  G_CALLBACK (view_row_activated_callback), chooser);
+
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (view));
 	g_signal_connect (selection, "changed", 
 			  G_CALLBACK (selection_changed_callback), chooser);
@@ -345,20 +363,6 @@ use_default_clicked_callback (GtkWidget *button, gpointer user_data)
 		       signals[USE_DEFAULT], 0);
 }
 
-static GtkWidget *
-button_new_with_mnemonic (const gchar *stockid, const gchar *str)
-{
-	GtkWidget *image;
-	GtkWidget *button;
-	
-	button = gtk_button_new_with_mnemonic (str);
-	image = gtk_image_new_from_stock (stockid, GTK_ICON_SIZE_BUTTON);
-	
-	gtk_button_set_image (GTK_BUTTON (button), image);
-
-	return button;
-}
-
 static void
 add_buttons (NautilusColumnChooser *chooser)
 {
@@ -368,8 +372,7 @@ add_buttons (NautilusColumnChooser *chooser)
 	box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 8);
 	gtk_widget_show (box);
 	
-	chooser->details->move_up_button = button_new_with_mnemonic (GTK_STOCK_GO_UP,
-								     _("Move _Up"));
+	chooser->details->move_up_button = gtk_button_new_with_mnemonic (_("Move _Up"));
 	g_signal_connect (chooser->details->move_up_button, 
 			  "clicked",  G_CALLBACK (move_up_clicked_callback),
 			  chooser);
@@ -378,8 +381,7 @@ add_buttons (NautilusColumnChooser *chooser)
 	gtk_box_pack_start (GTK_BOX (box), chooser->details->move_up_button,
 			    FALSE, FALSE, 0);
 
-	chooser->details->move_down_button = button_new_with_mnemonic (GTK_STOCK_GO_DOWN,
-								       _("Move Dow_n"));
+	chooser->details->move_down_button = gtk_button_new_with_mnemonic (_("Move Dow_n"));
 	g_signal_connect (chooser->details->move_down_button, 
 			  "clicked",  G_CALLBACK (move_down_clicked_callback),
 			  chooser);
