@@ -36,6 +36,7 @@ static const char *default_column_order[] = {
 	"size",
 	"type",
 	"date_modified",
+	"date_accessed",
 	"owner",
 	"group",
 	"permissions",
@@ -79,6 +80,14 @@ get_builtin_columns (void)
 					       "description", _("The date the file was modified."),
 					       "default-sort-order", GTK_SORT_DESCENDING,
 					       NULL));
+	columns = g_list_append (columns,
+				 g_object_new (NAUTILUS_TYPE_COLUMN,
+					       "name", "date_accessed",
+					       "attribute", "date_accessed",
+					       "label", _("Accessed"),
+					       "description", _("The date the file was accessed."),
+					       "default-sort-order", GTK_SORT_DESCENDING,
+					       NULL));
 
 	columns = g_list_append (columns,
 				 g_object_new (NAUTILUS_TYPE_COLUMN,
