@@ -78,6 +78,7 @@ file_icons_changed (NautilusFile *file,
 	pixbuf = nautilus_file_get_icon_pixbuf (fcd->details->destination,
 						NAUTILUS_ICON_SIZE_LARGE,
 						TRUE,
+						gtk_widget_get_scale_factor (fcd->details->dest_image),
 						NAUTILUS_FILE_ICON_FLAGS_USE_THUMBNAILS);
 
 	gtk_image_set_from_pixbuf (GTK_IMAGE (fcd->details->dest_image), pixbuf);
@@ -86,6 +87,7 @@ file_icons_changed (NautilusFile *file,
 	pixbuf = nautilus_file_get_icon_pixbuf (fcd->details->source,
 						NAUTILUS_ICON_SIZE_LARGE,
 						TRUE,
+						gtk_widget_get_scale_factor (fcd->details->src_image),
 						NAUTILUS_FILE_ICON_FLAGS_USE_THUMBNAILS);
 
 	gtk_image_set_from_pixbuf (GTK_IMAGE (fcd->details->src_image), pixbuf);
@@ -221,6 +223,7 @@ file_list_ready_cb (GList *files,
 	pixbuf = nautilus_file_get_icon_pixbuf (dest,
 						NAUTILUS_ICON_SIZE_LARGE,
 						TRUE,
+						gtk_widget_get_scale_factor (fcd->details->titles_vbox),
 						NAUTILUS_FILE_ICON_FLAGS_USE_THUMBNAILS);
 	details->dest_image = gtk_image_new_from_pixbuf (pixbuf);
 	gtk_box_pack_start (GTK_BOX (details->first_hbox),
@@ -231,6 +234,7 @@ file_list_ready_cb (GList *files,
 	pixbuf = nautilus_file_get_icon_pixbuf (src,
 						NAUTILUS_ICON_SIZE_LARGE,
 						TRUE,
+						gtk_widget_get_scale_factor (fcd->details->titles_vbox),
 						NAUTILUS_FILE_ICON_FLAGS_USE_THUMBNAILS);
 	details->src_image = gtk_image_new_from_pixbuf (pixbuf);
 	gtk_box_pack_start (GTK_BOX (details->second_hbox),
@@ -472,8 +476,8 @@ nautilus_file_conflict_dialog_init (NautilusFileConflictDialog *fcd)
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
 
 	/* Setup the dialog image */
-	widget = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING,
-					   GTK_ICON_SIZE_DIALOG);
+	widget = gtk_image_new_from_icon_name ("dialog-warning",
+					       GTK_ICON_SIZE_DIALOG);
 	gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
 	gtk_misc_set_alignment (GTK_MISC (widget), 0.5, 0.0);
 
@@ -518,8 +522,8 @@ nautilus_file_conflict_dialog_init (NautilusFileConflictDialog *fcd)
 
 	widget = gtk_button_new_with_label (_("Reset"));
 	gtk_button_set_image (GTK_BUTTON (widget),
-			      gtk_image_new_from_stock (GTK_STOCK_UNDO,
-							GTK_ICON_SIZE_MENU));
+			      gtk_image_new_from_icon_name ("edit-undo",
+							    GTK_ICON_SIZE_MENU));
 	gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 6);
 	g_signal_connect (widget, "clicked",
 			  G_CALLBACK (reset_button_clicked_cb), dialog);
@@ -537,7 +541,7 @@ nautilus_file_conflict_dialog_init (NautilusFileConflictDialog *fcd)
 
 	/* Add buttons */
 	gtk_dialog_add_buttons (dialog,
-				GTK_STOCK_CANCEL,
+				_("_Cancel"),
 				GTK_RESPONSE_CANCEL,
 				_("_Skip"),
 				CONFLICT_RESPONSE_SKIP,
