@@ -164,16 +164,16 @@ typedef enum
 void nautilus_global_preferences_init                      (void);
 char *nautilus_global_preferences_get_default_folder_viewer_preference_as_iid (void);
 
-GSettings *nautilus_preferences;
-GSettings *nautilus_icon_view_preferences;
-GSettings *nautilus_list_view_preferences;
-GSettings *nautilus_desktop_preferences;
-GSettings *nautilus_window_state;
-GSettings *gtk_filechooser_preferences;
-GSettings *gnome_lockdown_preferences;
-GSettings *gnome_background_preferences;
-GSettings *gnome_interface_preferences;
-GSettings *gnome_privacy_preferences;
+extern GSettings *nautilus_preferences;
+extern GSettings *nautilus_icon_view_preferences;
+extern GSettings *nautilus_list_view_preferences;
+extern GSettings *nautilus_desktop_preferences;
+extern GSettings *nautilus_window_state;
+extern GSettings *gtk_filechooser_preferences;
+extern GSettings *gnome_lockdown_preferences;
+extern GSettings *gnome_background_preferences;
+extern GSettings *gnome_interface_preferences;
+extern GSettings *gnome_privacy_preferences;
 
 G_END_DECLS
 
