@@ -40,6 +40,8 @@ struct _NautilusIconInfo
 	GdkPoint *attach_points;
 	char *display_name;
         char *icon_name;
+
+	gint  orig_scale;
 };
 
 struct _NautilusIconInfoClass
@@ -118,7 +120,8 @@ nautilus_icon_info_class_init (NautilusIconInfoClass *icon_info_class)
 }
 
 NautilusIconInfo *
-nautilus_icon_info_new_for_pixbuf (GdkPixbuf *pixbuf)
+nautilus_icon_info_new_for_pixbuf (GdkPixbuf *pixbuf,
+				   gint       scale)
 {
 	NautilusIconInfo *icon;
 
@@ -126,13 +129,16 @@ nautilus_icon_info_new_for_pixbuf (GdkPixbuf *pixbuf)
 
 	if (pixbuf) {
 		icon->pixbuf = g_object_ref (pixbuf);
-	} 
+	}
+
+	icon->orig_scale = scale;
 	
 	return icon;
 }
 
 static NautilusIconInfo *
-nautilus_icon_info_new_for_icon_info (GtkIconInfo *icon_info)
+nautilus_icon_info_new_for_icon_info (GtkIconInfo *icon_info,
+				      gint         scale)
 {
 	NautilusIconInfo *icon;
 	GdkPoint *points;
@@ -163,6 +169,8 @@ nautilus_icon_info_new_for_icon_info (GtkIconInfo *icon_info)
 		}
 		icon->icon_name = basename;
 	}
+
+	icon->orig_scale = scale;
 	
 	return icon;
 }
@@ -326,7 +334,8 @@ themed_icon_key_free (ThemedIconKey *key)
 
 NautilusIconInfo *
 nautilus_icon_info_lookup (GIcon *icon,
-			   int size)
+			   int size,
+			   int scale)
 {
 	NautilusIconInfo *icon_info;
 	GdkPixbuf *pixbuf;
@@ -354,17 +363,18 @@ nautilus_icon_info_lookup (GIcon *icon,
 
 		pixbuf = NULL;
 		stream = g_loadable_icon_load (G_LOADABLE_ICON (icon),
-					       size,
+					       size * scale,
 					       NULL, NULL, NULL);
 		if (stream) {
 			pixbuf = gdk_pixbuf_new_from_stream_at_scale (stream,
-								      size, size, TRUE,
+								      size * scale, size * scale,
+								      TRUE,
 								      NULL, NULL);
 			g_input_stream_close (stream, NULL, NULL);
 			g_object_unref (stream);
 		}
 
-		icon_info = nautilus_icon_info_new_for_pixbuf (pixbuf);
+		icon_info = nautilus_icon_info_new_for_pixbuf (pixbuf, scale);
 
 		key = loadable_icon_key_new (icon, size);
 		g_hash_table_insert (loadable_icon_cache, key, icon_info);
@@ -389,16 +399,17 @@ nautilus_icon_info_lookup (GIcon *icon,
 		names = g_themed_icon_get_names (G_THEMED_ICON (icon));
 
 		icon_theme = gtk_icon_theme_get_default ();
-		gtkicon_info = gtk_icon_theme_choose_icon (icon_theme, (const char **)names, size, 0);
+		gtkicon_info = gtk_icon_theme_choose_icon_for_scale (icon_theme, (const char **)names,
+								     size, scale, 0);
 
 		if (gtkicon_info == NULL) {
-			return nautilus_icon_info_new_for_pixbuf (NULL);
+			return nautilus_icon_info_new_for_pixbuf (NULL, scale);
 		}
 
 		filename = gtk_icon_info_get_filename (gtkicon_info);
 		if (filename == NULL) {
 			g_object_unref (gtkicon_info);
-			return nautilus_icon_info_new_for_pixbuf (NULL);
+			return nautilus_icon_info_new_for_pixbuf (NULL, scale);
 		}
 
 		lookup_key.filename = (char *)filename;
@@ -410,7 +421,7 @@ nautilus_icon_info_lookup (GIcon *icon,
 			return g_object_ref (icon_info);
 		}
 		
-		icon_info = nautilus_icon_info_new_for_icon_info (gtkicon_info);
+		icon_info = nautilus_icon_info_new_for_icon_info (gtkicon_info, scale);
 		
 		key = themed_icon_key_new (filename, size);
 		g_hash_table_insert (themed_icon_cache, key, icon_info);
@@ -422,10 +433,11 @@ nautilus_icon_info_lookup (GIcon *icon,
                 GdkPixbuf *pixbuf;
                 GtkIconInfo *gtk_icon_info;
 
-                gtk_icon_info = gtk_icon_theme_lookup_by_gicon (gtk_icon_theme_get_default (),
-                                                                icon,
-                                                                size,
-                                                                GTK_ICON_LOOKUP_GENERIC_FALLBACK);
+                gtk_icon_info = gtk_icon_theme_lookup_by_gicon_for_scale (gtk_icon_theme_get_default (),
+									  icon,
+									  size,
+									  scale,
+									  GTK_ICON_LOOKUP_GENERIC_FALLBACK);
                 if (gtk_icon_info != NULL) {
                         pixbuf = gtk_icon_info_load_icon (gtk_icon_info, NULL);
                         g_object_unref (gtk_icon_info);
@@ -433,7 +445,7 @@ nautilus_icon_info_lookup (GIcon *icon,
                         pixbuf = NULL;
                 }
 
-		icon_info = nautilus_icon_info_new_for_pixbuf (pixbuf);
+		icon_info = nautilus_icon_info_new_for_pixbuf (pixbuf, scale);
 
 		if (pixbuf != NULL) {
 			g_object_unref (pixbuf);
@@ -445,20 +457,22 @@ nautilus_icon_info_lookup (GIcon *icon,
 
 NautilusIconInfo *
 nautilus_icon_info_lookup_from_name (const char *name,
-				     int size)
+				     int size,
+				     int scale)
 {
 	GIcon *icon;
 	NautilusIconInfo *info;
 
 	icon = g_themed_icon_new (name);
-	info = nautilus_icon_info_lookup (icon, size);
+	info = nautilus_icon_info_lookup (icon, size, scale);
 	g_object_unref (icon);
 	return info;
 }
 
 NautilusIconInfo *
 nautilus_icon_info_lookup_from_path (const char *path,
-				     int size)
+				     int size,
+				     int scale)
 {
 	GFile *icon_file;
 	GIcon *icon;
@@ -466,7 +480,7 @@ nautilus_icon_info_lookup_from_path (const char *path,
 
 	icon_file = g_file_new_for_path (path);
 	icon = g_file_icon_new (icon_file);
-	info = nautilus_icon_info_lookup (icon, size);
+	info = nautilus_icon_info_lookup (icon, size, scale);
 	g_object_unref (icon);
 	g_object_unref (icon_file);
 	return info;
@@ -527,9 +541,9 @@ nautilus_icon_info_get_pixbuf_nodefault_at_size (NautilusIconInfo  *icon,
 
 	if (pixbuf == NULL)
 	  return NULL;
-	  
-	w = gdk_pixbuf_get_width (pixbuf);
-	h = gdk_pixbuf_get_height (pixbuf);
+
+	w = gdk_pixbuf_get_width (pixbuf) / icon->orig_scale;
+	h = gdk_pixbuf_get_height (pixbuf) / icon->orig_scale;
 	s = MAX (w, h);
 	if (s == forced_size) {
 		return pixbuf;
@@ -554,8 +568,8 @@ nautilus_icon_info_get_pixbuf_at_size (NautilusIconInfo  *icon,
 
 	pixbuf = nautilus_icon_info_get_pixbuf (icon);
 
-	w = gdk_pixbuf_get_width (pixbuf);
-	h = gdk_pixbuf_get_height (pixbuf);
+	w = gdk_pixbuf_get_width (pixbuf) / icon->orig_scale;
+	h = gdk_pixbuf_get_height (pixbuf) / icon->orig_scale;
 	s = MAX (w, h);
 	if (s == forced_size) {
 		return pixbuf;
