@@ -506,6 +506,26 @@ search_callback_add_pending_file_callbacks (SearchCallback *callback)
 	search_callback_add_file_callbacks (callback);
 }
 
+static void
+search_directory_ensure_loaded (NautilusSearchDirectory *search)
+{
+	if (search->details->search_loaded) {
+		return;
+	}
+
+	search->details->search_loaded = TRUE;
+	nautilus_directory_emit_done_loading (NAUTILUS_DIRECTORY (search));
+
+	/* Add all file callbacks */
+	g_list_foreach (search->details->pending_callback_list,
+			(GFunc)search_callback_add_pending_file_callbacks, NULL);
+	search->details->callback_list = g_list_concat (search->details->callback_list,
+							search->details->pending_callback_list);
+
+	g_list_free (search->details->pending_callback_list);
+	search->details->pending_callback_list = NULL;
+}
+
 static void
 search_engine_hits_added (NautilusSearchEngine *engine, GList *hits, 
 			  NautilusSearchDirectory *search)
@@ -554,19 +574,7 @@ search_engine_hits_added (NautilusSearchEngine *engine, GList *hits,
 	nautilus_file_emit_changed (file);
 	nautilus_file_unref (file);
 
-	if (!search->details->search_loaded) {
-		search->details->search_loaded = TRUE;
-		nautilus_directory_emit_done_loading (NAUTILUS_DIRECTORY (search));
-
-		/* Add all file callbacks */
-		g_list_foreach (search->details->pending_callback_list,
-				(GFunc)search_callback_add_pending_file_callbacks, NULL);
-		search->details->callback_list = g_list_concat (search->details->callback_list,
-								search->details->pending_callback_list);
-
-		g_list_free (search->details->pending_callback_list);
-		search->details->pending_callback_list = NULL;
-	}
+	search_directory_ensure_loaded (search);
 }
 
 static void
@@ -581,6 +589,12 @@ search_engine_error (NautilusSearchEngine *engine, const char *error_message, Na
 	g_error_free (error);
 }
 
+static void
+search_engine_finished (NautilusSearchEngine *engine, NautilusSearchDirectory *search)
+{
+	search_directory_ensure_loaded (search);
+}
+
 static void
 search_force_reload (NautilusDirectory *directory)
 {
@@ -762,6 +776,9 @@ nautilus_search_directory_init (NautilusSearchDirectory *search)
 	g_signal_connect (search->details->engine, "error",
 			  G_CALLBACK (search_engine_error),
 			  search);
+	g_signal_connect (search->details->engine, "finished",
+			  G_CALLBACK (search_engine_finished),
+			  search);
 }
 
 static void
