@@ -251,35 +251,15 @@ nautilus_bookmark_list_append (NautilusBookmarkList *bookmarks,
 	g_return_if_fail (NAUTILUS_IS_BOOKMARK_LIST (bookmarks));
 	g_return_if_fail (NAUTILUS_IS_BOOKMARK (bookmark));
 
-	insert_bookmark_internal (bookmarks, 
-				  nautilus_bookmark_copy (bookmark), 
-				  -1);
+	if (g_list_find_custom (bookmarks->list, bookmark,
+				nautilus_bookmark_compare_with) != NULL) {
+		return;
+	}
 
+	insert_bookmark_internal (bookmarks, g_object_ref (bookmark), -1);
 	nautilus_bookmark_list_save_file (bookmarks);
 }
 
-/**
- * nautilus_bookmark_list_contains:
- *
- * Check whether a bookmark with matching name and url is already in the list.
- * @bookmarks: NautilusBookmarkList to check contents of.
- * @bookmark: NautilusBookmark to match against.
- * 
- * Return value: TRUE if matching bookmark is in list, FALSE otherwise
- **/
-gboolean
-nautilus_bookmark_list_contains (NautilusBookmarkList *bookmarks, 
-				 NautilusBookmark     *bookmark)
-{
-	g_return_val_if_fail (NAUTILUS_IS_BOOKMARK_LIST (bookmarks), FALSE);
-	g_return_val_if_fail (NAUTILUS_IS_BOOKMARK (bookmark), FALSE);
-
-	return g_list_find_custom (bookmarks->list,
-				   (gpointer)bookmark, 
-				   nautilus_bookmark_compare_with) 
-		!= NULL;
-}
-
 /**
  * nautilus_bookmark_list_delete_item_at:
  * 
@@ -337,44 +317,6 @@ nautilus_bookmark_list_move_item (NautilusBookmarkList *bookmarks,
 	nautilus_bookmark_list_save_file (bookmarks);
 }
 
-/**
- * nautilus_bookmark_list_delete_items_with_uri:
- * 
- * Delete all bookmarks with the given uri.
- * @bookmarks: the list of bookmarks.
- * @uri: The uri to match.
- **/
-void
-nautilus_bookmark_list_delete_items_with_uri (NautilusBookmarkList *bookmarks, 
-				      	      const char           *uri)
-{
-	GList *node, *next;
-	gboolean list_changed;
-	char *bookmark_uri;
-
-	g_return_if_fail (NAUTILUS_IS_BOOKMARK_LIST (bookmarks));
-	g_return_if_fail (uri != NULL);
-
-	list_changed = FALSE;
-	for (node = bookmarks->list; node != NULL;  node = next) {
-		next = node->next;
-
-		bookmark_uri = nautilus_bookmark_get_uri (NAUTILUS_BOOKMARK (node->data));
-		if (g_strcmp0 (bookmark_uri, uri) == 0) {
-			bookmarks->list = g_list_remove_link (bookmarks->list, node);
-			stop_monitoring_bookmark (bookmarks, NAUTILUS_BOOKMARK (node->data));
-			g_object_unref (node->data);
-			g_list_free_1 (node);
-			list_changed = TRUE;
-		}
-		g_free (bookmark_uri);
-	}
-
-	if (list_changed) {
-		nautilus_bookmark_list_save_file (bookmarks);
-	}
-}
-
 /**
  * nautilus_bookmark_list_insert_item:
  * 
@@ -391,10 +333,7 @@ nautilus_bookmark_list_insert_item (NautilusBookmarkList *bookmarks,
 	g_return_if_fail (NAUTILUS_IS_BOOKMARK_LIST (bookmarks));
 	g_return_if_fail (index <= g_list_length (bookmarks->list));
 
-	insert_bookmark_internal (bookmarks,
-				  nautilus_bookmark_copy (new_bookmark), 
-				  index);
-
+	insert_bookmark_internal (bookmarks, g_object_ref (new_bookmark), index);
 	nautilus_bookmark_list_save_file (bookmarks);
 }
 
@@ -417,39 +356,49 @@ nautilus_bookmark_list_item_at (NautilusBookmarkList *bookmarks, guint index)
 }
 
 /**
- * nautilus_bookmark_list_item_with_uri:
+ * nautilus_bookmark_list_item_with_location:
  *
- * Get the bookmark with the specified URI, if any
+ * Get the bookmark with the specified location, if any
  * @bookmarks: the list of bookmarks.
- * @uri: an URI
+ * @location: a #GFile
+ * @index: location where to store bookmark index, or %NULL
  *
- * Return value: the bookmark with URI @uri, or %NULL.
+ * Return value: the bookmark with location @location, or %NULL.
  **/
 NautilusBookmark *
-nautilus_bookmark_list_item_with_uri (NautilusBookmarkList *bookmarks,
-				      const gchar	   *uri)
+nautilus_bookmark_list_item_with_location (NautilusBookmarkList *bookmarks,
+					   GFile                *location,
+					   guint                *index)
 {
 	GList *node;
-	gchar *bookmark_uri;
+	GFile *bookmark_location;
 	NautilusBookmark *bookmark;
 	gboolean found = FALSE;
+	guint idx;
 
 	g_return_val_if_fail (NAUTILUS_IS_BOOKMARK_LIST (bookmarks), NULL);
-	g_return_val_if_fail (uri != NULL, NULL);
+	g_return_val_if_fail (G_IS_FILE (location), NULL);
+
+	idx = 0;
 
 	for (node = bookmarks->list; node != NULL; node = node->next) {
 		bookmark = node->data;
-		bookmark_uri = nautilus_bookmark_get_uri (bookmark);
+		bookmark_location = nautilus_bookmark_get_location (bookmark);
 
-		if (g_strcmp0 (uri, bookmark_uri) == 0) {
+		if (g_file_equal (location, bookmark_location)) {
 			found = TRUE;
 		}
 
-		g_free (bookmark_uri);
+		g_object_unref (bookmark_location);
 
 		if (found) {
+			if (index) {
+				*index = idx;
+			}
 			return bookmark;
 		}
+
+		idx++;
 	}
 
 	return NULL;
@@ -497,6 +446,7 @@ load_callback (GObject *source,
 	contents = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (res));
 
 	if (contents == NULL) {
+		op_processed_cb (self);
 		return;
 	}
 
@@ -716,6 +666,28 @@ nautilus_bookmark_list_save_file (NautilusBookmarkList *bookmarks)
 	}
 }
 
+gboolean
+nautilus_bookmark_list_can_bookmark_location (NautilusBookmarkList *list,
+					      GFile                *location)
+{
+	NautilusBookmark *bookmark;
+	gboolean is_builtin;
+
+	if (nautilus_bookmark_list_item_with_location (list, location, NULL)) {
+		return FALSE;
+	}
+
+	if (nautilus_is_home_directory (location)) {
+		return FALSE;
+	}
+
+	bookmark = nautilus_bookmark_new (location, NULL);
+	is_builtin = nautilus_bookmark_get_is_builtin (bookmark);
+	g_object_unref (bookmark);
+
+	return !is_builtin;
+}
+
 /**
  * nautilus_bookmark_list_new:
  * 
