@@ -135,6 +135,11 @@ static const SortCriterion sort_criteria[] = {
 		"modification date",
 		"Sort by Modification Date"
 	},
+	{
+		NAUTILUS_FILE_SORT_BY_ATIME,
+		"access date",
+		"Sort by Access Date"
+	},
 	{
 		NAUTILUS_FILE_SORT_BY_TRASHED_TIME,
 		"trashed",
@@ -592,7 +597,7 @@ get_default_sort_order (NautilusFile *file, gboolean *reversed)
 		}
 
 		retval = CLAMP (default_sort_order, NAUTILUS_FILE_SORT_BY_DISPLAY_NAME,
-				NAUTILUS_FILE_SORT_BY_MTIME);
+				NAUTILUS_FILE_SORT_BY_ATIME);
 	}
 
 	return retval;
@@ -1133,6 +1138,10 @@ static const GtkRadioActionEntry arrange_radio_entries[] = {
     N_("By Modification _Date"), NULL,
     N_("Keep icons sorted by modification date in rows"),
     NAUTILUS_FILE_SORT_BY_MTIME },
+  { "Sort by Access Date", NULL,
+    N_("By _Access Date"), NULL,
+    N_("Keep icons sorted by access date in rows"),
+    NAUTILUS_FILE_SORT_BY_ATIME },
   { NAUTILUS_ACTION_SORT_TRASH_TIME, NULL,
     N_("By T_rash Time"), NULL,
     N_("Keep icons sorted by trash time in rows"),
