@@ -146,7 +146,7 @@ validate_uri (NautilusConnectServerDialog *dialog,
 			g_set_error_literal (error,
 					     G_IO_ERROR,
 					     G_IO_ERROR_NOT_SUPPORTED,
-					     _("Don't recognize this file server type."));
+					     _("This file server type is not recognized."));
 		}
 		g_free (scheme);
 	} else {
@@ -698,7 +698,7 @@ nautilus_connect_server_dialog_init (NautilusConnectServerDialog *dialog)
 	dialog->details->browse_button = button;
 
 	gtk_dialog_add_button (GTK_DIALOG (dialog),
-			       GTK_STOCK_CANCEL,
+			       _("_Cancel"),
 			       GTK_RESPONSE_CANCEL);
 	gtk_dialog_add_button (GTK_DIALOG (dialog),
 			       _("C_onnect"),
