@@ -94,11 +94,7 @@ main (int argc, char *argv[])
 #endif
 
 	/* Run the nautilus application. */
-	application = g_object_new (NAUTILUS_TYPE_APPLICATION,
-				    "application-id", "org.gnome.Nautilus",
-				    "flags", G_APPLICATION_HANDLES_OPEN,
-				    "inactivity-timeout", 12000,
-				    NULL);
+	application = nautilus_application_new ();
 
 	/* hold indefinitely if we're asked to persist */
 	if (g_getenv ("NAUTILUS_PERSIST") != NULL) {
