@@ -402,8 +402,10 @@ nautilus_toolbar_constructed (GObject *obj)
 
 	G_OBJECT_CLASS (nautilus_toolbar_parent_class)->constructed (obj);
 
+	gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (self)),
+				     "header-bar");
+
 	self->priv->toolbar = toolbar = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-	g_object_set (toolbar, "margin", 6, NULL);
 	gtk_container_add (GTK_CONTAINER (self), toolbar);
 
 	rtl = gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL;
@@ -440,9 +442,9 @@ nautilus_toolbar_constructed (GObject *obj)
 	gtk_box_pack_start (GTK_BOX (toolbar), box, FALSE, FALSE, 0);
 
 	if (rtl) {
-		gtk_widget_set_margin_left (box, 12);
+		gtk_widget_set_margin_left (box, 6);
 	} else {
-		gtk_widget_set_margin_right (box, 12);
+		gtk_widget_set_margin_right (box, 6);
 	}
 
 	/* regular path bar */
@@ -489,9 +491,9 @@ nautilus_toolbar_constructed (GObject *obj)
 
 	gtk_container_add (GTK_CONTAINER (toolbar), box);
 	if (rtl) {
-		gtk_widget_set_margin_right (box, 12);
+		gtk_widget_set_margin_right (box, 6);
 	} else {
-		gtk_widget_set_margin_left (box, 12);
+		gtk_widget_set_margin_left (box, 6);
 	}
 
 	/* Action Menu */
@@ -505,9 +507,9 @@ nautilus_toolbar_constructed (GObject *obj)
 
 	gtk_container_add (GTK_CONTAINER (toolbar), button);
 	if (rtl) {
-		gtk_widget_set_margin_right (button, 12);
+		gtk_widget_set_margin_right (button, 6);
 	} else {
-		gtk_widget_set_margin_left (button, 12);
+		gtk_widget_set_margin_left (button, 6);
 	}
 
 	/* Separator and Close */
@@ -515,14 +517,16 @@ nautilus_toolbar_constructed (GObject *obj)
 	gtk_container_add (GTK_CONTAINER (toolbar), separator);
 
 	if (rtl) {
-		gtk_widget_set_margin_right (separator, 8);
+		gtk_widget_set_margin_right (separator, 6);
 	} else {
-		gtk_widget_set_margin_left (separator, 8);
+		gtk_widget_set_margin_left (separator, 6);
 	}
 
 	button = gtk_button_new_from_icon_name ("window-close-symbolic",
 						GTK_ICON_SIZE_MENU);
 	gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
+	gtk_style_context_add_class (gtk_widget_get_style_context (button),
+				     "titlebutton");
 	g_signal_connect (button, "clicked",
 			  G_CALLBACK (close_button_clicked), self);
 	gtk_container_add (GTK_CONTAINER (toolbar), button);
