@@ -352,10 +352,11 @@ get_drop_filename (const char *text)
 	int last_nonspace = -1;
 	int num_attrs;
 	PangoLogAttr *attrs;
+	gchar *current_char;
 
-	num_attrs = MIN (g_utf8_strlen (text, -1) + 1, MAX_LEN_FILENAME);
+	num_attrs = MIN (g_utf8_strlen (text, -1), MAX_LEN_FILENAME) + 1;
 	attrs = g_new (PangoLogAttr, num_attrs);
-	g_utf8_strncpy (trimmed, text, num_attrs);
+	g_utf8_strncpy (trimmed, text, num_attrs - 1);
 	pango_get_log_attrs (trimmed, -1, -1, pango_language_get_default (), attrs, num_attrs);
 
 	/* since the end of the text will always match a word boundary don't include it */
@@ -383,6 +384,15 @@ get_drop_filename (const char *text)
 		filename = g_strdup (_("Dropped Text.txt"));
 	}
 
+	/* Remove any invalid characters */
+	for (current_char = filename;
+	     *current_char;
+	     current_char = g_utf8_next_char (current_char)) {
+		if ( G_IS_DIR_SEPARATOR ( g_utf8_get_char (current_char))) {
+			*current_char = '-';
+		}
+	}
+
 	return filename;
 }
 
@@ -520,10 +530,14 @@ nautilus_view_handle_hover (NautilusView *view,
 {
 	NautilusWindowSlot *slot;
 	GFile *location;
+	GFile *current_location;
 
 	slot = nautilus_view_get_nautilus_window_slot (view);
 
 	location = g_file_new_for_uri (target_uri);
-	nautilus_window_slot_open_location (slot, location, 0);
+	current_location = nautilus_window_slot_get_location (slot);
+	if (! (current_location != NULL && g_file_equal(location, current_location))) {
+		nautilus_window_slot_open_location (slot, location, 0);
+	}
 	g_object_unref (location);
 }
