@@ -467,22 +467,23 @@ action_view_radio_changed (GtkRadioAction *action,
 
 static const GtkActionEntry main_entries[] = {
   /* name, stock id, label */  { "Help", NULL, N_("_Help") },
-  /* name, stock id */         { NAUTILUS_ACTION_CLOSE, GTK_STOCK_CLOSE,
+  /* name, stock id */         { NAUTILUS_ACTION_CLOSE, NULL,
   /* label, accelerator */       N_("_Close"), "<control>W",
   /* tooltip */                  N_("Close this folder"),
                                  G_CALLBACK (action_close_window_slot_callback) },
-                               { NAUTILUS_ACTION_PREFERENCES, GTK_STOCK_PREFERENCES,
+                               { NAUTILUS_ACTION_PREFERENCES, NULL,
                                  N_("Prefere_nces"),               
                                  NULL, N_("Edit Nautilus preferences"),
                                  G_CALLBACK (action_preferences_callback) },
-  /* name, stock id, label */  { NAUTILUS_ACTION_UP, GTK_STOCK_GO_UP, N_("Open _Parent"),
-                                 "<alt>Up", N_("Open the parent folder"),
+  /* name, stock id */         { NAUTILUS_ACTION_UP, NULL,
+  /* label, accelerator */	 N_("Open _Parent"), "<alt>Up",
+				 N_("Open the parent folder"),
                                  G_CALLBACK (action_up_callback) },
-  /* name, stock id */         { NAUTILUS_ACTION_STOP, GTK_STOCK_STOP,
+  /* name, stock id */         { NAUTILUS_ACTION_STOP, NULL,
   /* label, accelerator */       N_("_Stop"), NULL,
   /* tooltip */                  N_("Stop loading the current location"),
                                  G_CALLBACK (action_stop_callback) },
-  /* name, stock id */         { NAUTILUS_ACTION_RELOAD, GTK_STOCK_REFRESH,
+  /* name, stock id */         { NAUTILUS_ACTION_RELOAD, NULL,
   /* label, accelerator */       N_("_Reload"), "<control>R",
   /* tooltip */                  N_("Reload the current location"),
                                  G_CALLBACK (action_reload_callback) },
@@ -490,7 +491,7 @@ static const GtkActionEntry main_entries[] = {
   /* label, accelerator */       "ReloadAccel", "F5",
   /* tooltip */                  NULL,
                                  G_CALLBACK (action_reload_callback) },
-  /* name, stock id */         { NAUTILUS_ACTION_HELP, GTK_STOCK_HELP,
+  /* name, stock id */         { NAUTILUS_ACTION_HELP, NULL,
   /* label, accelerator */       N_("_All Topics"), "F1",
   /* tooltip */                  N_("Display Nautilus help"),
                                  G_CALLBACK (action_nautilus_manual_callback) },
@@ -510,11 +511,11 @@ static const GtkActionEntry main_entries[] = {
   /* label, accelerator */       N_("Share and transfer files"), NULL,
   /* tooltip */                  N_("Easily transfer files to your contacts and devices from the file manager."),
                                  G_CALLBACK (action_nautilus_manual_callback) },
-  /* name, stock id */         { NAUTILUS_ACTION_ABOUT, GTK_STOCK_ABOUT,
+  /* name, stock id */         { NAUTILUS_ACTION_ABOUT, NULL,
   /* label, accelerator */       N_("_About"), NULL,
   /* tooltip */                  N_("Display credits for the creators of Nautilus"),
                                  G_CALLBACK (action_about_nautilus_callback) },
-  /* name, stock id */         { NAUTILUS_ACTION_ZOOM_IN, GTK_STOCK_ZOOM_IN,
+  /* name, stock id */         { NAUTILUS_ACTION_ZOOM_IN, NULL,
   /* label, accelerator */       N_("Zoom _In"), "<control>plus",
   /* tooltip */                  N_("Increase the view size"),
                                  G_CALLBACK (action_zoom_in_callback) },
@@ -526,7 +527,7 @@ static const GtkActionEntry main_entries[] = {
   /* label, accelerator */       "ZoomInAccel2", "<control>KP_Add",
   /* tooltip */                  NULL,
                                  G_CALLBACK (action_zoom_in_callback) },
-  /* name, stock id */         { NAUTILUS_ACTION_ZOOM_OUT, GTK_STOCK_ZOOM_OUT,
+  /* name, stock id */         { NAUTILUS_ACTION_ZOOM_OUT, NULL,
   /* label, accelerator */       N_("Zoom _Out"), "<control>minus",
   /* tooltip */                  N_("Decrease the view size"),
                                  G_CALLBACK (action_zoom_out_callback) },
@@ -534,7 +535,7 @@ static const GtkActionEntry main_entries[] = {
   /* label, accelerator */       "ZoomOutAccel", "<control>KP_Subtract",
   /* tooltip */                  NULL,
                                  G_CALLBACK (action_zoom_out_callback) },
-  /* name, stock id */         { NAUTILUS_ACTION_ZOOM_NORMAL, GTK_STOCK_ZOOM_100,
+  /* name, stock id */         { NAUTILUS_ACTION_ZOOM_NORMAL, NULL,
   /* label, accelerator */       N_("Normal Si_ze"), "<control>0",
   /* tooltip */                  N_("Use the normal view size"),
                                  G_CALLBACK (action_zoom_normal_callback) },
@@ -546,29 +547,37 @@ static const GtkActionEntry main_entries[] = {
   /* label, accelerator */       N_("_Home"), "<alt>Home",
   /* tooltip */                  N_("Open your personal folder"),
                                  G_CALLBACK (action_home_callback) },
-  /* name, stock id, label */  { NAUTILUS_ACTION_NEW_WINDOW, "window-new", N_("New _Window"),
-                                 "<control>N", N_("Open another Nautilus window for the displayed location"),
+  /* name, stock id */         { NAUTILUS_ACTION_NEW_WINDOW, "window-new",
+				 N_("New _Window"), "<control>N",
+				 N_("Open another Nautilus window for the displayed location"),
                                  G_CALLBACK (action_new_window_callback) },
-  /* name, stock id, label */  { NAUTILUS_ACTION_NEW_TAB, "tab-new", N_("New _Tab"),
-                                 "<control>T", N_("Open another tab for the displayed location"),
+  /* name, stock id */         { NAUTILUS_ACTION_NEW_TAB, "tab-new",
+				 N_("New _Tab"), "<control>T",
+				 N_("Open another tab for the displayed location"),
                                  G_CALLBACK (action_new_tab_callback) },
-  /* name, stock id, label */  { NAUTILUS_ACTION_CLOSE_ALL_WINDOWS, NULL, N_("Close _All Windows"),
-                                 "<control>Q", N_("Close all Navigation windows"),
+  /* name, stock id */         { NAUTILUS_ACTION_CLOSE_ALL_WINDOWS, NULL,
+				 N_("Close _All Windows"), "<control>Q",
+				 N_("Close all Navigation windows"),
                                  G_CALLBACK (action_close_all_windows_callback) },
-  /* name, stock id, label */  { NAUTILUS_ACTION_BACK, "go-previous-symbolic", N_("_Back"),
-				 "<alt>Left", N_("Go to the previous visited location"),
+  /* name, stock id */         { NAUTILUS_ACTION_BACK, "go-previous-symbolic",
+				 N_("_Back"), "<alt>Left",
+				 N_("Go to the previous visited location"),
 				 G_CALLBACK (action_back_callback) },
-  /* name, stock id, label */  { NAUTILUS_ACTION_FORWARD, "go-next-symbolic", N_("_Forward"),
-				 "<alt>Right", N_("Go to the next visited location"),
+  /* name, stock id */         { NAUTILUS_ACTION_FORWARD, "go-next-symbolic",
+				 N_("_Forward"), "<alt>Right",
+				 N_("Go to the next visited location"),
 				 G_CALLBACK (action_forward_callback) },
-  /* name, stock id, label */  { NAUTILUS_ACTION_ENTER_LOCATION, NULL, N_("Enter _Location…"),
-                                 "<control>L", N_("Specify a location to open"),
+  /* name, stock id */         { NAUTILUS_ACTION_ENTER_LOCATION, NULL,
+				 N_("Enter _Location…"), "<control>L",
+				 N_("Specify a location to open"),
                                  G_CALLBACK (action_enter_location_callback) },
-  /* name, stock id, label */  { NAUTILUS_ACTION_ADD_BOOKMARK, GTK_STOCK_ADD, N_("Bookmark this Location"),
-                                 "<control>d", N_("Add a bookmark for the current location"),
+  /* name, stock id */         { NAUTILUS_ACTION_ADD_BOOKMARK, NULL,
+				 N_("Bookmark this Location"), "<control>d",
+				 N_("Add a bookmark for the current location"),
                                  G_CALLBACK (action_add_bookmark_callback) },
-  /* name, stock id, label */  { NAUTILUS_ACTION_EDIT_BOOKMARKS, NULL, N_("_Bookmarks…"),
-                                 "<control>b", N_("Display and edit bookmarks"),
+  /* name, stock id */         { NAUTILUS_ACTION_EDIT_BOOKMARKS, NULL,
+				 N_("_Bookmarks…"), "<control>b",
+				 N_("Display and edit bookmarks"),
                                  G_CALLBACK (action_bookmarks_callback) },
   { "TabsPrevious", NULL, N_("_Previous Tab"), "<control>Page_Up",
     N_("Activate previous tab"),
@@ -582,7 +591,7 @@ static const GtkActionEntry main_entries[] = {
   { "TabsMoveRight", NULL, N_("Move Tab _Right"), "<shift><control>Page_Down",
     N_("Move current tab to right"),
     G_CALLBACK (action_tabs_move_right_callback) },
-  /* name, stock id */         { NAUTILUS_ACTION_LOCATION_PROPERTIES, GTK_STOCK_PROPERTIES,
+  /* name, stock id */         { NAUTILUS_ACTION_LOCATION_PROPERTIES, NULL,
   /* label, accelerator */       N_("P_roperties"), NULL,
   /* tooltip */                  N_("View or modify the properties of this folder"),
 				 G_CALLBACK (action_location_properties_callback) },
@@ -820,7 +829,7 @@ add_extension_menu_items (NautilusWindow *window,
 		
 		g_object_get (item, "menu", &menu, NULL);
 		
-		action = nautilus_action_from_menu_item (item);
+		action = nautilus_action_from_menu_item (item, GTK_WIDGET (window));
 		gtk_action_group_add_action_with_accel (action_group, action, NULL);
 		
 		path = g_build_path ("/", POPUP_PATH_EXTENSION_ACTIONS, subdirectory, NULL);
